summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorjohnwc_yeh <johnwc_yeh@compal.corp-partner.google.com>2022-05-09 11:18:32 +0800
committerChromeos LUCI <chromeos-scoped@luci-project-accounts.iam.gserviceaccount.com>2022-05-12 09:04:44 +0000
commite0b1b73469d097591a154fa6c5e1b0117c27651b (patch)
tree402fa345ae513afe7fefcb5b2e0df4270f7b45c2
parente85c5bab8282346ef8ec0d9a4c480be3e0e8780f (diff)
downloadchrome-ec-e0b1b73469d097591a154fa6c5e1b0117c27651b.tar.gz
mithrax: felwinter renamed to mithrax
Felwinter renamed to mithrax. BUG=b:223091246 BRANCH=None TEST=make BOARD=mithrax Signed-off-by: johnwc_yeh <johnwc_yeh@compal.corp-partner.google.com> Change-Id: Ibfa865d2309cc44a6f1af1d2f7d8e90eca30c8b5 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3631726 Reviewed-by: Ko Ko <ko_ko@compal.corp-partner.google.com> Reviewed-by: Ricky Chang <rickytlchang@chromium.org>
-rw-r--r--board/mithrax/battery.c4
-rw-r--r--board/mithrax/board.c2
-rw-r--r--board/mithrax/board.h6
-rw-r--r--board/mithrax/build.mk4
-rw-r--r--board/mithrax/charger_isl9241.c2
-rw-r--r--board/mithrax/ec.tasklist2
-rw-r--r--board/mithrax/fans.c2
-rw-r--r--board/mithrax/fw_config.c12
-rw-r--r--board/mithrax/fw_config.h16
-rw-r--r--board/mithrax/gpio.inc2
-rw-r--r--board/mithrax/i2c.c2
-rw-r--r--board/mithrax/keyboard.c6
-rw-r--r--board/mithrax/led.c4
-rw-r--r--board/mithrax/pwm.c2
-rw-r--r--board/mithrax/sensors.c6
-rw-r--r--board/mithrax/usbc_config.c2
-rw-r--r--board/mithrax/usbc_config.h4
17 files changed, 39 insertions, 39 deletions
diff --git a/board/mithrax/battery.c b/board/mithrax/battery.c
index 08c129d118..2c5c0bce9a 100644
--- a/board/mithrax/battery.c
+++ b/board/mithrax/battery.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*
@@ -10,7 +10,7 @@
#include "compile_time_macros.h"
/*
- * Battery info for all Brya battery types. Note that the fields
+ * Battery info for all Mithrax battery types. Note that the fields
* start_charging_min/max and charging_min/max are not used for the charger.
* The effective temperature limits are given by discharging_min/max_c.
*
diff --git a/board/mithrax/board.c b/board/mithrax/board.c
index 892c4d85bd..b391301cc8 100644
--- a/board/mithrax/board.c
+++ b/board/mithrax/board.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
diff --git a/board/mithrax/board.h b/board/mithrax/board.h
index d8bcd11705..fe42604e93 100644
--- a/board/mithrax/board.h
+++ b/board/mithrax/board.h
@@ -1,9 +1,9 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-/* Brya board configuration */
+/* Mithrax board configuration */
#ifndef __CROS_EC_BOARD_H
#define __CROS_EC_BOARD_H
@@ -81,7 +81,7 @@
#define CONFIG_USBC_PPC_SYV682X
#define CONFIG_USBC_PPC_NX20P3483
-/* TODO: b/177608416 - measure and check these values on brya */
+/* TODO: b/177608416 - measure and check these values on mithrax */
#define PD_POWER_SUPPLY_TURN_ON_DELAY 30000 /* us */
#define PD_POWER_SUPPLY_TURN_OFF_DELAY 30000 /* us */
#define PD_VCONN_SWAP_DELAY 5000 /* us */
diff --git a/board/mithrax/build.mk b/board/mithrax/build.mk
index 5a0a20b5e6..c4345d8de0 100644
--- a/board/mithrax/build.mk
+++ b/board/mithrax/build.mk
@@ -1,9 +1,9 @@
# -*- makefile -*-
-# Copyright 2021 The Chromium OS Authors. All rights reserved.
+# Copyright 2022 The Chromium OS Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
#
-# Brya board specific files build
+# Mithrax board specific files build
#
CHIP:=npcx
diff --git a/board/mithrax/charger_isl9241.c b/board/mithrax/charger_isl9241.c
index 8bb38754dd..10bc45b333 100644
--- a/board/mithrax/charger_isl9241.c
+++ b/board/mithrax/charger_isl9241.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
diff --git a/board/mithrax/ec.tasklist b/board/mithrax/ec.tasklist
index 6d995d6b44..96c9128df4 100644
--- a/board/mithrax/ec.tasklist
+++ b/board/mithrax/ec.tasklist
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
diff --git a/board/mithrax/fans.c b/board/mithrax/fans.c
index 636364a6de..1f75eb6ca3 100644
--- a/board/mithrax/fans.c
+++ b/board/mithrax/fans.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
diff --git a/board/mithrax/gpio.inc b/board/mithrax/gpio.inc
index 86f71a9ea3..06f2dece3e 100644
--- a/board/mithrax/gpio.inc
+++ b/board/mithrax/gpio.inc
@@ -1,6 +1,6 @@
/* -*- mode:c -*-
*
- * Copyright 2021 The Chromium OS Authors. All rights reserved.
+ * Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
diff --git a/board/mithrax/i2c.c b/board/mithrax/i2c.c
index a850c12544..7833d1c154 100644
--- a/board/mithrax/i2c.c
+++ b/board/mithrax/i2c.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
diff --git a/board/mithrax/keyboard.c b/board/mithrax/keyboard.c
index a8cbf72238..f07b2dda17 100644
--- a/board/mithrax/keyboard.c
+++ b/board/mithrax/keyboard.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
@@ -24,7 +24,7 @@ __override struct keyboard_scan_config keyscan_config = {
},
};
-static const struct ec_response_keybd_config felwinter_kb = {
+static const struct ec_response_keybd_config mithrax_kb = {
.num_top_row_keys = 10,
.action_keys = {
TK_BACK, /* T1 */
@@ -44,5 +44,5 @@ static const struct ec_response_keybd_config felwinter_kb = {
__override const struct ec_response_keybd_config
*board_vivaldi_keybd_config(void)
{
- return &felwinter_kb;
+ return &mithrax_kb;
}
diff --git a/board/mithrax/led.c b/board/mithrax/led.c
index 3b7e649470..61fc766e57 100644
--- a/board/mithrax/led.c
+++ b/board/mithrax/led.c
@@ -1,8 +1,8 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*
- * Power and battery LED control for felwinter
+ * Power and battery LED control for mithrax
*/
#include "chipset.h"
diff --git a/board/mithrax/pwm.c b/board/mithrax/pwm.c
index fea431c4ce..ffc90e910a 100644
--- a/board/mithrax/pwm.c
+++ b/board/mithrax/pwm.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
diff --git a/board/mithrax/sensors.c b/board/mithrax/sensors.c
index fd3f721947..fff002dda6 100644
--- a/board/mithrax/sensors.c
+++ b/board/mithrax/sensors.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
@@ -168,7 +168,7 @@ const struct temp_sensor_t temp_sensors[] = {
BUILD_ASSERT(ARRAY_SIZE(temp_sensors) == TEMP_SENSOR_COUNT);
/*
- * TODO(b/180681346): update for Alder Lake/brya
+ * TODO(b/180681346): update for Alder Lake/mithrax
*
* Tiger Lake specifies 100 C as maximum TDP temperature. THRMTRIP# occurs at
* 130 C. However, sensor is located next to DDR, so we need to use the lower
@@ -192,7 +192,7 @@ BUILD_ASSERT(ARRAY_SIZE(temp_sensors) == TEMP_SENSOR_COUNT);
__maybe_unused static const struct ec_thermal_config thermal_cpu = THERMAL_CPU;
/*
- * TODO(b/180681346): update for Alder Lake/brya
+ * TODO(b/180681346): update for Alder Lake/mithrax
*
* Inductor limits - used for both charger and PP3300 regulator
*
diff --git a/board/mithrax/usbc_config.c b/board/mithrax/usbc_config.c
index 14eec1a145..f0cd83f5e2 100644
--- a/board/mithrax/usbc_config.c
+++ b/board/mithrax/usbc_config.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
diff --git a/board/mithrax/usbc_config.h b/board/mithrax/usbc_config.h
index 9f0a26210f..aaf1d02b10 100644
--- a/board/mithrax/usbc_config.h
+++ b/board/mithrax/usbc_config.h
@@ -1,9 +1,9 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-/* Brya board-specific USB-C configuration */
+/* Mithrax board-specific USB-C configuration */
#ifndef __CROS_EC_USBC_CONFIG_H
#define __CROS_EC_USBC_CONFIG_H
diff --git a/board/mithrax/fw_config.c b/board/mithrax/fw_config.c
index 4228394d5b..a430c39a0e 100644
--- a/board/mithrax/fw_config.c
+++ b/board/mithrax/fw_config.c
@@ -1,4 +1,4 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
@@ -11,20 +11,20 @@
#define CPRINTS(format, args...) cprints(CC_CHIPSET, format, ## args)
-static union brya_cbi_fw_config fw_config;
+static union mithrax_cbi_fw_config fw_config;
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
* FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
* initialized.
*/
-static const union brya_cbi_fw_config fw_config_defaults = {
+static const union mithrax_cbi_fw_config fw_config_defaults = {
.usb_db = DB_USB3_PS8815,
.kb_bl = KEYBOARD_BACKLIGHT_ENABLED,
};
/****************************************************************************
- * Brya FW_CONFIG access
+ * Mithrax FW_CONFIG access
*/
void board_init_fw_config(void)
{
@@ -34,7 +34,7 @@ void board_init_fw_config(void)
}
}
-union brya_cbi_fw_config get_fw_config(void)
+union mithrax_cbi_fw_config get_fw_config(void)
{
return fw_config;
}
@@ -11,20 +11,20 @@
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
- * FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
+ * FW_CONFIG defaults for mithrax if the CBI.FW_CONFIG data is not
* initialized.
*/
diff --git a/board/mithrax/fw_config.h b/board/mithrax/fw_config.h
index 5f5f956b61..0b6da0568d 100644
--- a/board/mithrax/fw_config.h
+++ b/board/mithrax/fw_config.h
@@ -1,17 +1,17 @@
-/* Copyright 2021 The Chromium OS Authors. All rights reserved.
+/* Copyright 2022 The Chromium OS Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-#ifndef __BOARD_BRYA_FW_CONFIG_H_
-#define __BOARD_BRYA_FW_CONFIG_H_
+#ifndef __BOARD_MITHRAX_FW_CONFIG_H_
+#define __BOARD_MITHRAX_FW_CONFIG_H_
#include <stdint.h>
/****************************************************************************
* CBI FW_CONFIG layout for felwinter board.
*
* Source of truth is the project/brya/felwinter/config.star configuration file.
*/
enum ec_cfg_usb_db_type {
@@ -34,7 +34,7 @@ enum ec_cfg_stylus_type {
STYLUS_PRSENT = 1
};
-union brya_cbi_fw_config {
+union mithrax_cbi_fw_config {
struct {
enum ec_cfg_usb_db_type usb_db : 3;
uint32_t wifi : 2;
@@ -54,7 +54,7 @@ union brya_cbi_fw_config {
*
* @return the FW_CONFIG for the board.
*/
-union brya_cbi_fw_config get_fw_config(void);
+union mithrax_cbi_fw_config get_fw_config(void);
/**
* Get the USB daughter board type from FW_CONFIG.
@@ -70,7 +70,7 @@ enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void);
*/
enum ec_cfg_usb_mb_type ec_cfg_usb_mb_type(void);
-#endif /* __BOARD_BRYA_FW_CONFIG_H_ */
+#endif /* __BOARD_MITHRAX_FW_CONFIG_H_ */
/**
* Get the stylus type from FW_CONFIG.
@@ -1,17 +1,17 @@
#include <stdint.h>
/****************************************************************************
- * CBI FW_CONFIG layout for felwinter board.
+ * CBI FW_CONFIG layout for mithrax board.
*
@@ -1,17 +1,17 @@
*
- * Source of truth is the project/brya/felwinter/config.star configuration file.
+ * Source of truth is the project/brya/mithrax/config.star configuration file.
*/
enum ec_cfg_usb_db_type {